rendered paste bodyalias ClonesXs {
if ($dialog(p.cloning)) { dialog -v p.cloning | $decode(Y29weQ==,m) }
else { dialog -md p.cloning p.cloning | $decode(Y29weQ==,m) }
}
dialog p.cloning {
title "ClonesX"
size -1 -1 268 205
option dbu
tab "Connection", 200, 1 1 265 200
box "Server", 8, 5 20 186 21, tab 200
text "Host/Ip:", 9, 7 28 20 8, result tab 200
edit "", 10, 28 27 92 10, tab 200 autohs
text "Port:", 1, 123 29 17 8, tab 200
combo 12, 142 27 46 50, tab 200 size edit drop
box "Nick", 34, 5 44 111 22, tab 200
radio "", 35, 8 53 7 10, tab 200 flat
radio "Other", 36, 57 53 22 10, tab 200 flat
combo 37, 16 52 41 50, tab 200 size drop
edit "", 38, 80 53 34 10, tab 200 autohs
box "Connection", 45, 6 101 110 67, tab 200
text "Number of clones:", 49, 10 110 48 20, tab 200
combo 50, 68 108 43 80, tab 200 size edit drop
text "Mode:", 215, 10 121 15 8, tab 200
combo 47, 68 120 43 50, tab 200 size drop
button "&Connect", 48, 10 144 101 10, disable tab 200 flat
button "&Disconnect", 52, 10 156 101 10, tab 200 flat
box "Debug", 219, 119 44 142 143, tab 200
edit "", 44, 121 51 138 134, tab 200 read multi autohs vsbar
box "State", 39, 6 67 110 31, tab 200
text "Connected clones:", 40, 10 75 47 8, tab 200
text "Open sockets:", 42, 10 86 41 8, tab 200
button "Clear Debug", 53, 6 174 110 13, tab 200 flat
text "-", 41, 78 76 34 8, tab 200
text "-", 43, 78 86 34 8, tab 200
text "Delay:", 390, 10 133 25 8, tab 200
combo 391, 68 132 43 60, tab 200 size edit drop
link "Xenon", 361, 199 28 54 8, tab 200
tab "Firewall", 201
box "Proxy", 236, 3 18 88 170, tab 201
box "Socks 4", 234, 90 18 88 170, tab 201
box "Socks 5", 235, 177 18 88 170, tab 201
text "Host/Ip:", 55, 5 26 20 8, tab 201
edit "", 2, 26 25 62 10, tab 201 autohs
text "Port:", 56, 5 36 17 8, tab 201
edit "", 3, 26 36 62 10, tab 201 autohs
button "&Add", 5, 5 47 39 9, disable tab 201 flat
button "&Import", 6, 49 47 39 9, tab 201 flat
button "&Delete", 7, 5 57 39 9, tab 201 flat
button "Delete A&ll", 244, 49 57 39 9, tab 201 flat
list 4, 5 68 85 118, tab 201 size hsbar vsbar
list 69, 92 68 85 118, tab 201 size hsbar vsbar
button "&Delete", 72, 92 57 39 9, tab 201 flat
button "Delete A&ll", 256, 136 57 39 9, tab 201 flat
button "&Import", 71, 136 47 39 9, tab 201 flat
button "&Add", 70, 92 47 39 9, disable tab 201 flat
text "Port:", 67, 92 36 17 8, tab 201
edit "", 68, 113 36 62 10, tab 201 autohs
edit "", 66, 113 25 62 10, tab 201 autohs
text "Host/Ip:", 65, 92 26 20 8, tab 201
text "Host/Ip:", 74, 179 26 20 8, tab 201
edit "", 75, 200 25 62 10, tab 201 autohs
edit "", 77, 200 36 62 10, tab 201 autohs
text "Port:", 76, 179 36 17 8, tab 201
button "&Add", 79, 179 47 39 9, disable tab 201 flat
button "&Import", 80, 223 47 39 9, tab 201 flat
button "Delete A&ll", 265, 223 57 39 9, tab 201 flat
button "&Delete", 81, 179 57 39 9, tab 201 flat
list 78, 179 68 85 118, tab 201 size hsbar vsbar
tab "Actions", 202
box "Actions", 305, 3 19 261 86, tab 202
button "Msg", 310, 9 71 37 10, disable tab 202 flat
button "Notice", 311, 9 82 37 10, disable tab 202 flat
button "Ping", 309, 9 60 37 10, disable tab 202 flat
button "Version", 308, 9 49 37 10, disable tab 202 flat
button "Part", 307, 9 38 37 10, disable tab 202 flat
button "Join", 306, 9 27 37 10, disable tab 202 flat
text "Channel:", 313, 47 28 25 8, tab 202
button "Command", 312, 9 93 37 10, disable tab 202 flat
edit "", 314, 81 27 75 10, tab 202 autohs
text "Channel:", 315, 47 40 25 8, tab 202
edit "", 316, 81 38 75 10, tab 202 autohs
edit "", 318, 81 49 75 10, tab 202 autohs
text "Channel/Nick:", 317, 47 50 34 8, tab 202
text "Channel/Nick:", 319, 47 61 34 8, tab 202
edit "", 320, 81 60 75 10, tab 202 autohs
text "Channel/Nick:", 321, 47 72 34 8, tab 202
edit "", 322, 81 71 75 10, tab 202 autohs
text "Message:", 323, 160 72 24 8, tab 202
edit "", 324, 183 71 75 10, tab 202 autohs
text "Channel/Nick:", 325, 47 83 34 8, tab 202
edit "", 326, 81 82 75 10, tab 202 autohs
text "Message:", 327, 160 83 24 8, tab 202
edit "", 328, 183 82 75 10, tab 202 autohs
edit "", 329, 47 93 211 10, tab 202 autohs
edit "b0tz-r-cumn-", 331, 202 28 56 10, tab 202 autohs
button "Nick Change", 330, 158 28 42 10, disable tab 202 flat
box "From...", 332, 158 40 100 29, tab 202
radio "Global", 333, 163 47 27 10, disable tab 202 flat
radio "Selected", 334, 212 47 42 10, disable tab 202 flat
radio "Group 1", 335, 163 56 30 10, disable tab 202 flat
radio "Group 2", 336, 193 56 30 10, disable tab 202 flat
radio "Group 3", 337, 225 56 30 10, disable tab 202 flat
box "Nick List", 338, 3 105 261 85, tab 202
list 339, 5 112 53 76, disable tab 202 size extsel vsbar
button "Add to Group 1", 340, 59 124 39 11, disable tab 202 flat
button "Add to Group 2", 341, 59 143 39 11, disable tab 202 flat
box "Group 3", 370, 207 110 54 79, tab 202
button "Delete", 371, 209 118 19 8, disable tab 202 flat
button "Delete all", 372, 228 118 31 8, disable tab 202 flat
list 373, 208 126 52 62, disable tab 202 size vsbar
list 369, 154 126 52 62, disable tab 202 size vsbar
button "Delete all", 368, 174 118 31 8, disable tab 202 flat
button "Delete", 367, 155 118 19 8, disable tab 202 flat
box "Group 2", 366, 153 110 54 79, tab 202
list 351, 100 126 52 62, disable tab 202 size vsbar
button "Delete All", 350, 120 118 31 8, disable tab 202 flat
button "Delete", 349, 101 118 19 8, disable tab 202 flat
box "Group 1", 348, 99 110 54 79, tab 202
button "Add to Group 3", 342, 59 161 39 11, disable tab 202 flat
tab "Overtake", 11
box "Control", 14, 5 16 126 120, tab 11
button "Start", 15, 59 51 30 8, tab 11 flat
text " Channel:", 13, 7 32 28 8, tab 11
edit "#", 16, 37 31 84 10, tab 11 autohs
text " Overtake:", 17, 7 51 50 8, tab 11
button "Stop", 18, 91 51 30 8, disable tab 11 flat
text " Clones Mass", 19, 7 60 50 8, tab 11
button "Op", 20, 59 60 30 8, tab 11 flat
box "Kick Reasons", 22, 132 85 127 94, tab 11
list 23, 135 93 120 74, tab 11 size
button "Add", 24, 136 168 40 8, tab 11 flat
button "Del", 25, 177 168 40 8, tab 11 flat
box "Protected Nicks", 26, 132 19 127 64, tab 11
list 27, 134 26 122 46, tab 11 size
button "Add", 28, 136 73 40 8, tab 11 flat
button "Del", 29, 180 73 40 8, tab 11 flat
box "Protected Tags", 46, 4 137 127 42, tab 11
list 51, 6 144 122 24, tab 11 size
button "Add", 54, 7 168 40 8, tab 11 flat
button "Del", 57, 49 168 40 8, tab 11 flat
edit "Authnick", 58, 7 105 50 10, tab 11
edit "Authpw", 59, 7 115 50 10, tab 11
button "Authen", 60, 8 126 30 8, tab 11 flat
button "Join", 61, 6 42 25 8, tab 11 flat
text " L/Q Reop", 62, 7 78 25 8, tab 11
text " L/Q Invite", 63, 7 87 29 8, tab 11
button "Reop", 64, 59 78 62 8, tab 11 flat
button "Invite", 73, 59 87 62 8, tab 11 flat
text " O-Topic setzen", 84, 7 69 40 8, tab 11
button "Set", 85, 59 69 62 8, tab 11 flat
button "invite", 21, 91 60 30 8, tab 11 flat
button "Join 10", 97, 33 42 25 8, tab 11 flat
button "Rejoin", 98, 91 42 30 8, tab 11 flat
button "+x", 99, 40 126 15 8, tab 11 flat
text " Ban *!*@*", 100, 7 96 30 8, tab 11
button "Set", 104, 59 96 30 8, tab 11 flat
button "Unset", 105, 91 96 30 8, tab 11 flat
button "Op Clones", 106, 60 123 30 8, tab 11 flat
text " Main IRC Command:", 107, 59 114 65 8, tab 11
button "Topic", 108, 91 123 30 8, tab 11 flat
button "Part", 109, 60 42 29 8, tab 11 flat
button "Nickchange", 110, 59 105 62 8, tab 11 flat
box "Topic", 111, 4 180 260 19, tab 11
button "Add", 113, 200 188 30 8, tab 11 flat
button "Del", 114, 231 188 30 8, tab 11 flat
text "ClonesXs v1.2", 115, 182 5 86 8, disable tab 11
text " Clones:", 88, 7 23 22 8, tab 11
text " ", 90, 29 23 22 8, tab 11
list 91, 6 187 193 10, tab 11 size
text " Sockets:", 92, 63 23 25 8, tab 11
text " ", 93, 88 23 35 8, tab 11
tab "About", 30
box "About", 31, 6 18 256 61, tab 30
text " ClonesXs Coder: Kraix", 32, 10 26 247 8, tab 30
text " Modded by: Xenon(uCiTakeu)", 33, 10 34 247 8, tab 30
text " Modded ClonesXs Version: 1.2", 82, 10 42 248 7, tab 30
text " IRC-Channel: #[Xenon]]", 83, 10 49 248 8, tab 30
text " Homepage: http://www.clanboardzone.de/Xenon", 86, 10 57 248 8, tab 30
text " Modded ClonesXs v1.2", 87, 10 65 248 8, tab 30
text "", 89, 4 191 236 8, disable tab 30
menu "File", 403
item "&Exit", 476, 403
menu "Specials", 411
item "Ip-Ports", 412, 411
menu "Nick List", 413, 411
menu "Nicks Change", 414, 413
item "Default List", 415, 414
item "List...", 416, 414
menu "Save nicks", 417, 413
item "Default List", 418, 417
item "List...", 419, 417
menu "Connect with list", 420, 413
item "Default List", 421, 420
item "List...", 422, 420
}
on 1:DIALOG:p.cloning:edit:*: {
if ($did == 2) || ($did == 3) { p.clon.fire.secl 2 3 5 }
if ($did == 66) || ($did == 68) { p.clon.fire.secl 66 68 70 }
if ($did == 75) || ($did == 77) { p.clon.fire.secl 75 77 79 }
if ($did == 10) || ($did == 12) || ($did == 38) || ($did == 50) {
p.cloning.conEcheck
}
if ($did == 38) { if ($len($did($dname,38)) > 6) { p.cloning.fal The length must be al least 6 chars. | did -r $dname 38 } }
if ($did == 314) {
if (& iswm $did($dname,$did).text) && ($left($did($dname,$did).text,1) == $chr(35)) did -e $dname 306
else did -b $dname 306
}
if ($did == 316) {
if (& iswm $did($dname,$did).text) && ($left($did($dname,$did).text,1) == $chr(35)) did -e $dname 307
else did -b $dname 307
}
if ($did == 318) {
if (& iswm $did($dname,$did).text) did -e $dname 308
else did -b $dname 308
}
if ($did == 320) {
if (& iswm $did($dname,$did).text) did -e $dname 309
else did -b $dname 309
}
if ($did == 322) || ($did == 324) {
if (& iswm $did($dname,322).text) && (* iswm $did($dname,324).text) did -e $dname 310
else did -b $dname 310
}
if ($did == 326) || ($did == 328) {
if (& iswm $did($dname,326).text) && (* iswm $did($dname,328).text) did -e $dname 311
else did -b $dname 311
}
if ($did == 329) {
if (* iswm $did($dname,$did).text) did -e $dname 312
else did -b $dname 312
}
if ($did == 331) {
if (& iswm $did($dname,$did).text) did -e $dname 330
else did -b $dname 330
}
}
alias -l p.cloning.conEcheck {
if ($dialog(p.cloning)) {
if (??* iswm $did($dname,10)) && ($abs($did($dname,12)) != 0) && ($abs($did($dname,50)) != 0) {
if ($did($dname,36).state == 0) { did -e $dname 48 | did -e $dname 421 | did -e $dname 422 }
elseif ($did($dname,38)) { did -e $dname 48 | did -e $dname 421 | did -e $dname 422 }
else { if ($did($dname,48).enabled == $true) { did -b $dname 48 | did -b $dname 421 | did -b $dname 422 } }
}
else { if ($did($dname,48).enabled == $true) { did -b $dname 48 | did -b $dname 421 | did -b $dname 422 } }
}
}
alias -l p.clon.fire.secl {
if ($dialog(p.cloning)) {
if (??* iswm $did($dname,$$1)) && ($abs($did($dname,$$2)) != 0) && ($did($dname,$$2)) { did -e $dname $$3 }
elseif ($did($dname,$$3).enabled == $true) { did -b $dname $$3 }
}
}
alias -l p.clon.fire.secl1 {
var %p.clon.fire.secl1 = $did($dname,$$2) $did($dname,$$3)
if ($dialog(p.cloning)) && (!$didwm($dname,$$1,%p.clon.fire.secl1)) {
did -i $dname $$1 $calc($did($dname,$$1).lines + 1) %p.clon.fire.secl1
}
}
alias -l p.cloning.fire.secl2 {
if ($dialog(p.cloning)) {
did -d $dname $$1 $$did($dname,$$1).sel
}
}
alias -l p.cloning.fire.secl3 {
if ($dialog(p.cloning)) {
var %p.cloning.proFile = $sfile($iif(%p.save.cloning.lstPath,%p.save.cloning.lstPath,C:\),Select the file where the list of proxyes is,Importa)
if (%p.cloning.proFile) {
set %p.save.cloning.lstPath $nofile(%p.cloning.proFile)
var %i = 1
while (%i <= $lines(%p.cloning.proFile)) {
var %p.cloning.proFile.p = $read(%p.cloning.proFile,%i)
if ($gettok(%p.cloning.proFile.p,0,58) == 2) { var %p.cloning.proFile.p = $gettok(%p.cloning.proFile.p,1,58) $gettok(%p.cloning.proFile.p,2,58) }
if (($gettok(%p.cloning.proFile.p,0,32) != 2) || ($abs($gettok(%p.cloning.proFile.p,2,32)) == 0)) {
p.cloning.fal The file must contain in every line the proxy and the port. Ex, one.proxy.com 8080 Ex2. other.proxy.com:8080
return
}
if (%p.cloning.proFile.p) && (!$didwm($dname,$$1,%p.cloning.proFile.p)) { did -i $dname $$1 $calc($did($dname,$$1).lines + 1) %p.cloning.proFile.p }
var %i = %i + 1
}
unset %p.cloning.proFile.p
}
}
}
alias -l p.cloning.ddnsd {
if ($dialog(p.cloning)) {
if ($did(p.cloning,47).text == Socks 4) || ($did(p.cloning,47).text == Socks 5) {
.enable #p.cloning.DdnsD
.dns $did(p.cloning,10).text
p.clon.stats -Resolving Host/Ip... $time
}
else { p.cloning.jj }
}
}
#p.cloning.DdnsD off
on 1:DNS: {
if ($dialog(p.cloning)) {
if ($iaddress) { var %resulto = $iaddress }
else { var %resulto = $naddress }
did -o p.cloning 10 1 %resulto
.disable #p.cloning.DdnsD
p.clon.stats -Resolved a %resulto $time
p.clon.stats -
p.cloning.jj
}
haltdef
}
#p.cloning.DdnsD end
on 1:DIALOG:p.cloning:sclick:*: {
if ($did == 15) {
var %x = 1
while ($did(339,%x) != $null) {
if ($did(339,%x) isop $did(16)) {
sockwrite -n $p.cloning.do.saSockN($did(339,%x)) MODE $did(16) +ilk 1 roflownt
var %x = 99999999
go.masskick $did(16)
}
inc %x
}
}
if ($did == 20) {
go.clonesop
}
if ($did == 21) {
go.clonesinvite
}
if ($did == 60) {
p.cloning.runcmd privmsg Q@CServe.quakenet.org : $+ auth $did($dname,58) $did($dname,59)
}
if ($did == 64) {
go.reop
}
if ($did == 73) {
go.invite
timer_invite 1 1 p.cloning.runcmd join $did($dname,16)
}
if ($did == 85) {
p.cloning.runcmd topic $did(16) : $+ $read(topic.proxy)
}
if ($did == 25 && $did(23).sel != $null) {
write -dl $+ $did(23).sel kick.reasons
did -d $dname 23 $did(23).sel
}
if ($did == 114 && $did(91).sel != $null) {
write -dl $+ $did(91).sel topic.proxy
did -d $dname 91 $did(91).sel
}
if ($did == 57 && $did(51).sel != $null) {
write -dl $+ $did(51).sel protected.tags
did -d $dname 51 $did(51).sel
}
if ($did == 61) {
p.cloning.runcmd join $did(16)
}
if ($did == 97) {
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,1)) join $did(16)
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,2)) join $did(16)
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,3)) join $did(16)
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,4)) join $did(16)
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,5)) join $did(16)
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,6)) join $did(16)
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,7)) join $did(16)
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,8)) join $did(16)
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,9)) join $did(16)
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,10)) join $did(16)
}
if ($did == 98) {
p.cloning.runcmd part $did(16)
p.cloning.runcmd join $did(16)
}
if ($did == 99) {
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,1)) mode $did(p.cloning,339,1) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,2)) mode $did(p.cloning,339,2) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,3)) mode $did(p.cloning,339,3) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,4)) mode $did(p.cloning,339,4) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,5)) mode $did(p.cloning,339,5) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,6)) mode $did(p.cloning,339,6) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,7)) mode $did(p.cloning,339,7) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,8)) mode $did(p.cloning,339,8) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,9)) mode $did(p.cloning,339,9) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,10)) mode $did(p.cloning,339,10) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,11)) mode $did(p.cloning,339,11) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,12)) mode $did(p.cloning,339,12) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,13)) mode $did(p.cloning,339,13) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,14)) mode $did(p.cloning,339,14) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,15)) mode $did(p.cloning,339,15) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,16)) mode $did(p.cloning,339,16) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,17)) mode $did(p.cloning,339,17) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,18)) mode $did(p.cloning,339,18) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,19)) mode $did(p.cloning,339,19) +x
sockwrite -n $p.cloning.do.saSockN($did(p.cloning,339,20)) mode $did(p.cloning,339,20) +x
}
if ($did == 104) {
p.cloning.runcmd ban $did(16) *!*@
}
if ($did == 105) {
p.cloning.runcmd ban -r $did(16) *!*@
}
if ($did == 106) {
/op.allclones #[Xenon]
}
if ($did == 108) {
/ot.topic
}
if ($did == 109) {
p.cloning.runcmd part $did(16)
}
if ($did == 110) {
p.cloning.runcmd nick %proxynick
}
if ($did == 29 && $did(27).sel != $null) {
write -dl $+ $did(27).sel protected.nicks
did -d $dname 27 $did(27).sel
}
if ($did == 24) {
var %r = $?="Enter a kick reason"
if (%r != $null) {
did -a $dname 23 %r
did -z $dname 23
write kick.reasons %r
}
}
if ($did == 113) {
var %proxytopic = $?="Enter a topic"
if (%proxytopic != $null) {
did -a $dname 91 %proxytopic
did -z $dname 91
write topic.proxy %proxytopic
}
}
if ($did == 54) {
var %r = $?="Enter a Tag"
if (%r != $null) {
did -a $dname 51 %r
did -z $dname 51
write protected.tags %r
}
}
if ($did == 28) {
var %r = $?="Enter a nick"
if (%r != $null) {
did -a $dname 27 %r
did -z $dname 27
write protected.nicks %r
}
}
if ($did == 18) {
.timer_masskick off
did -e $dname 15
did -b $dname 18
var %x = 1
while ($did(339,%x) != $null) {
if ($did(339,%x) isop $did(16)) {
sockwrite -n $p.cloning.do.saSockN($did(339,%x)) MODE $did(16) -ilk roflownt
var %x = 99999999
}
inc %x
}
}
if ($did == 53) { did -r $dname 44 }
if ($did == 36) { if ($did($dname,36).state == 1) && ($did($dname,38) == $null) { did -b $dname 48 | did -b $dname 421 | did -b $dname 422 } }
if ($did == 35) { if ($did($dname,5).enabled == $false) { did -e $dname 48 | did -e $dname 421 | did -e $dname 422 } }
;if ($did == 46) {
; if ($calc($dialog($dname).w / $dbuw) >= 216) && ($calc($dialog($dname).w / $dbuw) <= 219) { dialog -bs $dname -1 -1 322 160 | dialog -r $dname }
; else { dialog -bs $dname -1 -1 215 160 | dialog -r $dname }
;}
if ($did == 5) { p.clon.fire.secl1 4 2 3 }
if ($did == 70) { p.clon.fire.secl1 69 66 68 }
if ($did == 79) { p.clon.fire.secl1 78 75 77 }
if ($did == 7) { p.cloning.fire.secl2 4 }
if ($did == 72) { p.cloning.fire.secl2 69 }
if ($did == 81) { p.cloning.fire.secl2 78 }
if ($did == 6) { p.cloning.fire.secl3 4 }
if ($did == 71) { p.cloning.fire.secl3 69 }
if ($did == 80) { p.cloning.fire.secl3 78 }
if ($did == 48) { unset %p.cloning.Nlist.conn* | p.cloning.ddnsd }
if ($did == 52) {
if ($sock(p.cloning*)) {
var %p.cloning.go.kit = DIE YO!
if (%p.cloning.msg.quit != %p.cloning.go.kit) { set %p.cloning.msg.quit BAI }
.sockwrite -nt p.cloning.* quit : $+ %p.cloning.msg.quit
.timerPCloning.out 1 1 .sockclose p.cloning.*
}
;.remove CloneX.ini | .remove CloneXo.ini
if ($hget(p.cloning.a)) { hfree p.cloning.a }
.timerP.cloning.Recr off
p.cloning.recr 1
unset %p.cloning.pn %p.cloning.t | .timerp.cloning.* off | p.clon.stats | p.cloning.cmds
}
if ($did == 339) {
if ($did($dname,$did).sel) { did -e $dname 340 | did -e $dname 341 | did -e $dname 342 }
else { did -b $dname 340 | did -b $dname 341 | did -b $dname 342 }
}
if ($did == 244) { did -r $dname 4 }
if ($did == 256) { did -r $dname 69 }
if ($did == 265) { did -r $dname 78 }
if ($did == 340) && ($did($dname,339).sel) { p.cloning.nick.gr.ad 351 }
if ($did == 341) && ($did($dname,339).sel) { p.cloning.nick.gr.ad 369 }
if ($did == 342) && ($did($dname,339).sel) { p.cloning.nick.gr.ad 373 }
if ($did == 349) { did -d $dname 351 $$did($dname,351).sel }
if ($did == 367) { did -d $dname 369 $$did($dname,369).sel }
if ($did == 371) { did -d $dname 373 $$did($dname,373).sel }
if ($did == 350) { did -r $dname 351 }
if ($did == 368) { did -r $dname 369 }
if ($did == 372) { did -r $dname 373 }
if ($did == 306) { p.cloning.runcmd join $did($dname,314).text }
if ($did == 307) { p.cloning.runcmd part $did($dname,316).text }
if ($did == 308) { p.cloning.runcmd privmsg $did($dname,318).text : $+ $chr(1) $+ version $+ $chr(1) }
if ($did == 309) { p.cloning.runcmd privmsg $did($dname,320).text : $+ $chr(1) $+ ping $+ $chr(1) }
if ($did == 310) { p.cloning.runcmd privmsg $did($dname,322).text : $+ $did($dname,324).text }
if ($did == 311) { p.cloning.runcmd notice $did($dname,326).text : $+ $did($dname,328).text }
if ($did == 312) { p.cloning.runcmd $did($dname,329).text }
if ($did == 330) { p.cloning.runcmd nick $did($dname,331).text }
if ($did == 361) { run $did($dname,361).text }
}
on 1:DIALOG:p.cloning:menu:*: {
if ($did == 476) { set %p.save.cloning.srv $did($dname,10).text }
if ($did == 405) { run irc://irc.quakenet.eu.org/script-planet }
if ($did == 406) { run irc://irc.quakenet.eu.org/script-planet }
if ($did == 407) { run mailto:Xenon@clanboardzone.de?subject=ClonesX }
if ($did == 409) { run irc://irc.quakenet.eu.org/script-planet }
if ($did == 410) { run irc://irc.quakenet.eu.org/script-planet }
if ($did == 412) { p.cloning.ipports }
if ($did == 415) { p.cloning.list.nicksch $mircdirClXNickList.cfg }
if ($did == 416) { p.cloning.list.nicksch $sfile($mircdir,"Escoge el archivo") }
if ($did == 418) { p.cloning.list.save $mircdirClXNickList.cfg }
if ($did == 419) { p.cloning.list.save $sfile($mircdir,"Guardar en...",Guardar) }
if ($did == 421) {
unset %p.cloning.Nlist.conn*
set %p.cloning.Nlist.conn 1
if ($exists($mircdirClXNickList.cfg) == $false) { p.cloning.fal File not found! }
set %p.cloning.Nlist.conn.f $mircdirClXNickList.cfg
p.cloning.ddnsd
}
if ($did == 422) {
unset %p.cloning.Nlist.conn*
set %p.cloning.Nlist.conn 1
set %p.cloning.Nlist.conn.f $sfile($mircdir,"Select file")
if (%p.cloning.Nlist.conn.f) { p.cloning.ddnsd }
}
if ($did == 441) { p.cloning.crdts }
}
alias -l p.cloning.nick.gr.ad {
if ($dialog(p.cloning)) {
var %i = 1
while ($did(p.cloning,339,$did(p.cloning,339,%i).sel).text) {
var %p.cloning.adgr1.nicks = $ifmatch
if (!$didwm(p.cloning,$$1,%p.cloning.adgr1.nicks)) { did -i p.cloning $$1 $calc($did(p.cloning,$$1).lines + 1) %p.cloning.adgr1.nicks }
var %i = %i + 1
}
}
}
alias -l p.cloning.jj {
if ($did(p.cloning,47).text == Normal) { p.clon.do }
elseif ($did(p.cloning,47).text == Proxy) {
if (!$did(p.cloning,4,1)) { p.cloning.fal Introduce some proxies in the configuration if you would connect with them. | p.cloning.recr 1 | return }
p.clon.do
}
elseif ($did(p.cloning,47).text == Socks 4) {
if (!$did(p.cloning,69,1)) { p.cloning.fal Introduce some proxies in the configuration if you would connect with Socks 4. | p.cloning.recr 1 | return }
;if ($abs($did($dname,10).text) == 0) { p.cloning.fal This protocol doesn't admit domain names (ip's only), /dns $did($dname,10).text and apply the result here ;) | return }
p.clon.do
}
elseif ($did(p.cloning,47).text == Socks 5) {
if (!$did(p.cloning,78,1)) { p.cloning.fal Introduce some proxies in the configuration if you would connect with Socks 5. | p.cloning.recr 1 | return }
;if ($abs($did($dname,10).text) == 0) { p.cloning.fal This protocol does admit domain names, but in this version of ClonesX it's bot implemented, so, /dns $did($dname,10).text and apply the result here ;) | return }
p.clon.do
}
}
alias -l p.clon.dodo {
if ($dialog(p.cloning)) && (!$sock($$1)) {
p.cloning.do.w $$1 0,0
;inc %p.cloning.n
.sockopen $$1-
if ($did(p.cloning,47).text == Normal) { var %p.clon.dodo = *Socket -Normal-: }
if ($did(p.cloning,47).text == Proxy) { var %p.clon.dodo = *Socket -Proxy-: }
if ($did(p.cloning,47).text == Socks 4) { var %p.clon.dodo = *Socket -Socks 4-: }
if ($did(p.cloning,47).text == Socks 5) { var %p.clon.dodo = *Socket -Socks 5-: }
p.clon.stats %p.clon.dodo $did(p.cloning,10) $did(p.cloning,12)
}
}
alias -l p.clon.do {
if ($dialog(p.cloning)) {
p.cloning.recr 0
var %p.cloning.delay = $did(p.cloning,391).text
if ($did(p.cloning,47).text == Normal) {
var %i = 1
while (%i <= $did(p.cloning,50).text) {
inc %p.cloning.t
.timerP.Cloning. [ $+ [ %p.cloning.t ] ] 1 $calc($iif(%i == 1,0,%i) * %p.cloning.delay) p.clon.dodo p.cloning. [ $+ [ %p.cloning.t ] ] $did(p.cloning,10) $did(p.cloning,12)
var %i = %i + 1
}
.timerP.cloning.Recr. [ $+ [ $rand(1,9999) ] ] 1 $calc(%i * %p.cloning.delay) p.cloning.recr 1
p.cloning.recr 0
}
elseif ($did(p.cloning,47).text == Proxy) {
var %i = 1
while (%i <= $did(p.cloning,50).text) {
if ($did(p.cloning,4,$calc(%p.cloning.pn + 1))) { inc %p.cloning.pn }
elseif ($did(p.cloning,4,1)) { set %p.cloning.pn 1 }
else { p.cloning.fal No hay proxyes. Config?ralo. | return }
inc %p.cloning.t
.timerP.Cloning. [ $+ [ %p.cloning.t ] ] 1 $calc($iif(%i == 1,0,%i) * %p.cloning.delay) p.clon.dodo p.cloning. [ $+ [ %p.cloning.t ] ] $gettok($did(p.cloning,4,%p.cloning.pn),1,32) $gettok($did(p.cloning,4,%p.cloning.pn),2,32)
var %i = %i + 1
}
.timerP.cloning.Recr. [ $+ [ $rand(1,9999) ] ] 1 $calc(%i * %p.cloning.delay) p.cloning.recr 1
p.cloning.recr 0
}
elseif ($did(p.cloning,47).text == Socks 4) {
var %i = 1
while (%i <= $did(p.cloning,50).text) {
if ($did(p.cloning,69,$calc(%p.cloning.pn4 + 1))) { inc %p.cloning.pn4 }
elseif ($did(p.cloning,69,1)) { set %p.cloning.pn4 1 }
else { p.cloning.fal No hay wingates. Config?ralo. | return }
inc %p.cloning.t
.timerP.Cloning. [ $+ [ %p.cloning.t ] ] 1 $calc($iif(%i == 1,0,%i) * %p.cloning.delay) p.clon.dodo p.cloning. [ $+ [ %p.cloning.t ] ] $gettok($did(p.cloning,69,%p.cloning.pn4),1,32) $gettok($did(p.cloning,69,%p.cloning.pn4),2,32)
var %i = %i + 1
}
.timerP.cloning.Recr. [ $+ [ $rand(1,9999) ] ] 1 $calc(%i * %p.cloning.delay) p.cloning.recr 1
p.cloning.recr 0
}
elseif ($did(p.cloning,47).text == Socks 5) {
var %i = 1
while (%i <= $did(p.cloning,50).text) {
if ($did(p.cloning,78,$calc(%p.cloning.pn5 + 1))) { inc %p.cloning.pn5 }
elseif ($did(p.cloning,78,1)) { set %p.cloning.pn5 1 }
else { p.cloning.fal No hay wingates. Config?ralo. | return }
inc %p.cloning.t
.timerP.Cloning. [ $+ [ %p.cloning.t ] ] 1 $calc($iif(%i == 1,0,%i) * %p.cloning.delay) p.clon.dodo p.cloning. [ $+ [ %p.cloning.t ] ] $gettok($did(p.cloning,78,%p.cloning.pn5),1,32) $gettok($did(p.cloning,78,%p.cloning.pn5),2,32)
var %i = %i + 1
}
.timerP.cloning.Recr. [ $+ [ $rand(1,9999) ] ] 1 $calc(%i * %p.cloning.delay) p.cloning.recr 1
p.cloning.recr 0
}
}
}
alias -l p.cloning.recr {
if ($dialog(p.cloning)) {
if ($$1 == 0) {
did -b p.cloning 10 | did -b p.cloning 12 | did -b p.cloning 47 | did -b p.cloning 50 | did -b p.cloning 391
did -b p.cloning 35 | did -b p.cloning 36 | did -b p.cloning 37 | did -b p.cloning 38 | did -b p.cloning 48 | did -b p.cloning 421 | did -b p.cloning 422
}
if ($$1 == 1) {
did -e p.cloning 10 | did -e p.cloning 12 | did -e p.cloning 47 | did -e p.cloning 50 | did -e p.cloning 391
did -e p.cloning 35 | did -e p.cloning 36 | did -e p.cloning 37 | did -e p.cloning 38
if (??* iswm $did(p.cloning,10)) && ($abs($did(p.cloning,12)) != 0) && ($abs($did(p.cloning,50)) != 0) {
if ($did(p.cloning,36).state == 0) { did -e p.cloning 48 | did -e p.cloning 421 | did -e p.cloning 422 }
elseif ($did(p.cloning,38)) { did -e p.cloning 48 | did -e p.cloning 421 | did -e p.cloning 422 }
}
}
}
}
alias -l p.clon.stats {
if ($dialog(p.cloning)) {
;did -o p.cloning 41 1 $iif($lines(CloneX.ini),$lines(CloneX.ini),-)
;did -o p.cloning 43 1 $iif($lines(CloneXo.ini),$lines(CloneXo.ini),-)
did -o p.cloning 41 1 $iif($p.cloning.dos.numCL(1),$p.cloning.dos.numCL(1),-)
did -o p.cloning 90 1 $iif($p.cloning.dos.numCL(1),$p.cloning.dos.numCL(1),-)
did -o p.cloning 43 1 $iif($p.cloning.dos.numCL(0),$p.cloning.dos.numCL(0),-)
did -o p.cloning 93 1 $iif($p.cloning.dos.numCL(0),$p.cloning.dos.numCL(0),-)
;echo -s DEBUG: Reales: $iif($p.cloning.dos.numC(1),$p.cloning.dos.numC(1),-) y Sockets: $iif($p.cloning.dos.numC(0),$p.cloning.dos.numC(0),-)
;did -o p.cloning 43 1 %p.cloning.n
if ($1-) { did -i p.cloning 44 $did(p.cloning,44).lines $1- }
}
}
on 1:DIALOG:p.cloning:init:0: {
.disable #p.cloning.DdnsD
did -c $dname 31
;.remove CloneX.ini | .remove CloneXo.ini
if ($hget(p.cloning.a)) { hfree p.cloning.a }
unset %p.cloning.pn %p.cloning.t | .timerp.cloning.* off
did -i $dname 12 1 6666 | did -i $dname 12 2 6667 | did -i $dname 12 3 6668 | did -i $dname 12 4 6669 | did -i $dname 12 5 7000 | did -c $dname 12 2
if (%p.save.cloning.srv) { did -i $dname 10 1 %p.save.cloning.srv }
did -c $dname 35 | did -i $dname 37 1 Aleatory | did -i $dname 37 2 Lemming | did -i $dname 37 3 Smurf | did -c $dname 37 1
did -c $dname 333 | did -b $dname 415 | did -b $dname 416 | did -b $dname 418 | did -b $dname 419 | did -b $dname 412
var %i = 1 | var %o = 1 | while (%o < 200) { did -i $dname 50 %i %o | var %i = %i + 1 | var %o = %o * 2 } | did -c $dname 50 1
var %i = 1 | var %o = 1 | while (%o < 20) { did -i $dname 391 %i %o | var %i = %i + 1 | var %o = %o * 2 } | did -i $dname 391 1 0 | did -c $dname 391 3
did -i $dname 47 1 Normal | did -i $dname 47 2 Proxy | did -i $dname 47 3 Socks 4 | did -i $dname 47 4 Socks 5 | did -c $dname 47 1
p.cloning.conEcheck
if ($file(kick.reasons) != $null) {
loadbuf -o $dname 23 kick.reasons
did -z $dname 23
}
if ($file(topic.proxy) != $null) {
loadbuf -o $dname 91 topic.proxy
did -z $dname 91
}
if ($file(protected.tags) != $null) {
loadbuf -o $dname 51 protected.tags
did -z $dname 51
}
if ($file(protected.nicks) != $null) {
loadbuf -o $dname 27 protected.nicks
did -z $dname 27
}
if ($file(proxy.perform) != $null) {
loadbuf -o $dname 33 proxy.perform
}
}
on 1:SOCKREAD:p.cloning.*: {
if ($dialog(p.cloning)) {
var %p.cloning.server = $did(p.cloning,10)
var %p.cloning.port = $did(p.cloning,12)
if ($sockerr != 0) { p.cloning.con.com $sockname | p.clon.stats Disconnected: %p.cloning.server %p.cloning.port - $+ %p.cloning.read $+ - | p.cloning.cmds }
else {
if ($did(p.cloning,47).text == Socks 4) {
if ($sock($sockname).mark != 1) {
sockread &p.cloning.bread
if ($bvar(&p.cloning.bread,1,2) == 0 90 ) { p.cloning.usIn $sockname | sockmark $sockname 1 }
if ($bvar(&p.cloning.bread,1,2) == 0 91 ) { p.cloning.con.com $sockname | p.clon.stats Disconnected: %p.cloning.server %p.cloning.port -Por Socks4- | .sockclose $sockname | p.cloning.cmds | return }
}
}
if ($did(p.cloning,47).text == Socks 5) {
if ($sock($sockname).mark != 1) {
sockread &p.cloning.bread
;echo -s bvar: $bvar(&p.cloning.bread,1,10)
if ($bvar(&p.cloning.bread,1,2) == 5 0) && ($bvar(&p.cloning.bread,3) != 0) {
;echo -s Protocolo Aceptado. Iniciando conexion.
var %p.cloning.portS5 = $gettok($longip(%p.cloning.port),3,46) $gettok($longip(%p.cloning.port),4,46)
var %p.cloning.serverS5 = $replace(%p.cloning.server,.,$chr(32))
bset &p.cloning.ssenndd 1 5 1 0 1 %p.cloning.serverS5 %p.cloning.portS5
sockwrite $sockname &p.cloning.ssenndd
;echo -s Sndg: bset &p.cloning.ssenndd 1 5 1 0 1 %p.cloning.serverS5 %p.cloning.portS5
}
if ( $bvar(&p.cloning.bread,1,2) == 5 255 ) { p.cloning.con.com $sockname | p.clon.stats Disconnected: %p.cloning.server %p.cloning.port -Por Socks5- | p.cloning.cmds }
if ( $bvar(&p.cloning.bread,1,3) == 5 0 0 ) { p.cloning.usIn $sockname | sockmark $sockname 1 }
if ( $bvar(&p.cloning.bread,1,3) == 5 4 0 ) { p.cloning.con.com $sockname | p.clon.stats Disconnected: %p.cloning.server %p.cloning.port -Por Socks5- | p.cloning.cmds }
if ( $bvar(&p.cloning.bread,1,3) == 5 5 0 ) { p.cloning.con.com $sockname | p.clon.stats Disconnected: %p.cloning.server %p.cloning.port -Por Socks5- | p.cloning.cmds }
if ( $bvar(&p.cloning.bread,1,3) == 5 9 0 ) { p.cloning.con.com $sockname | p.clon.stats Disconnected: %p.cloning.server %p.cloning.port -Por Socks5- | p.cloning.cmds }
}
}
sockread %p.cloning.read
var %p.cloning.sec1 = $gettok(%p.cloning.read,1,32)
var %p.cloning.sec2 = $gettok(%p.cloning.read,2,32)
var %p.cloning.sec3 = $gettok(%p.cloning.read,3,32)
;echo -s Rd: %p.cloning.read
if ($abs(%p.cloning.sec2)) && ($left(%p.cloning.sec1,1) == $chr(58)) {
if (%p.cloning.sec2 == 1) { p.cloning.do.w $sockname 1, $+ %p.cloning.sec3 | p.clon.stats -Connected: %p.cloning.server %p.cloning.port | p.cloning.cmds }
if (%p.cloning.sec2 == 433) && ($gettok($hget(p.cloning.a,$sockname),1,44) == 0) { p.cloning.usIn $sockname }
}
elseif (!$abs(%p.cloning.sec2)) {
if (%p.cloning.sec2 == NICK) {
if ($remove($gettok(%p.cloning.sec1,1,33),:) == $p.cloning.do.saNick($sockname)) && ($gettok(%p.cloning.sec1,2,33)) {
var %p.cloning.nnick = $remove(%p.cloning.sec3,:)
var %p.cloning.anick = $remove($gettok(%p.cloning.sec1,1,33),:)
if ($didwm(p.cloning,351,%p.cloning.anick)) { did -o p.cloning 351 $ifmatch %p.cloning.nnick }
if ($didwm(p.cloning,369,%p.cloning.anick)) { did -o p.cloning 369 $ifmatch %p.cloning.nnick }
if ($didwm(p.cloning,373,%p.cloning.anick)) { did -o p.cloning 373 $ifmatch %p.cloning.nnick }
p.cloning.do.w $sockname 1, $+ %p.cloning.nnick
p.cloning.nicks.act
}
}
}
if (%p.cloning.sec2 == 001 && $did(p.cloning,31).state == 1) {
var %x = 1
while ($did(p.cloning,33,%x) != $null) {
sockwrite -n $sockname $replace($did(p.cloning,33,%x),<nick>,$gettok(%p.cloning.read,2,44))
inc %x
}
}
if (%p.cloning.sec1 == PING) {
sockwrite -nt $sockname pong : $+ $remove(%p.cloning.sec2,:) | return
}
}
}
}
alias -l p.cloning.con.com {
;p.cloning.do.rw.o $$1
;p.cloning.do.rw $$1
if ($hget(p.cloning.a)) { hdel p.cloning.a $$1 }
}
on 1:SOCKOPEN:p.cloning.*: {
if ($dialog(p.cloning)) {
var %p.cloning.server = $did(p.cloning,10)
var %p.cloning.port = $did(p.cloning,12)
if ($sockerr != 0) { p.cloning.con.com $sockname | p.clon.stats Disconnected: %p.cloning.server %p.cloning.port -Session start- | p.cloning.cmds }
else {
;inc %p.cloning.nv | p.clon.stats on: %p.cloning.server %p.cloning.port
if ($did(p.cloning,47).text == Normal) { p.cloning.usIn $sockname }
elseif ($did(p.cloning,47).text == Proxy) {
sockwrite $sockname CONNECT %p.cloning.server $+ : $+ %p.cloning.port HTTP/1.0 $+ $CRLF $+ $CRLF
sockwrite $sockname $CRLF
.timerUs. [ $+ [ $sockname ] ] 1 2 p.cloning.usIn $sockname
}
elseif ($did(p.cloning,47).text == Socks 4) {
var %p.cloning.port1 = $gettok($longip(%p.cloning.port),3,46)
var %p.cloning.port2 = $gettok($longip(%p.cloning.port),4,46)
var %p.cloning.portS4 = $gettok($longip(%p.cloning.port),3,46) $gettok($longip(%p.cloning.port),4,46)
var %p.cloning.serverS4 = $replace(%p.cloning.server,.,$chr(32))
;bset &p.cloning.ssenndd 1 4 1 %p.cloning.port1 %p.cloning.port2 %p.cloning.server1 %p.cloning.server2 %p.cloning.server3 %p.cloning.server4 $CRLF
bset &p.cloning.ssenndd 1 4 1 %p.cloning.portS4 %p.cloning.serverS4 $CRLF
sockwrite $sockname &p.cloning.ssenndd
;echo -s sockopen pasado: bset &p.cloning.ssenndd 1 4 1 %p.cloning.port1 %p.cloning.port2 %p.cloning.server1 %p.cloning.server2 %p.cloning.server3 %p.cloning.server4
}
elseif ($did(p.cloning,47).text == Socks 5) {
bset &p.cloning.ssenndd 1 5 1 0
; -t?
sockwrite $sockname &p.cloning.ssenndd
}
}
}
}
alias -l p.cloning.cmds {
if ($dialog(p.cloning)) {
p.cloning.nicks.act
if ($did(p.cloning,314).enabled == $false) && ($did(p.cloning,41).text > 0) {
did -e p.cloning 314 | did -e p.cloning 316 | did -e p.cloning 318 | did -e p.cloning 320
did -e p.cloning 322 | did -e p.cloning 324 | did -e p.cloning 326 | did -e p.cloning 328
did -e p.cloning 329 | did -e p.cloning 331 | did -e p.cloning 333 | did -e p.cloning 339
did -e p.cloning 334 | did -e p.cloning 335 | did -e p.cloning 336 | did -e p.cloning 337
did -e p.cloning 372 | did -e p.cloning 373 | did -e p.cloning 369 | did -e p.cloning 368
did -e p.cloning 367 | did -e p.cloning 351 | did -e p.cloning 350 | did -e p.cloning 349 | did -e p.cloning 371
did -e p.cloning 415 | did -e p.cloning 416 | did -e p.cloning 418 | did -e p.cloning 419 | did -e p.cloning 412
}
else {
if ($did(p.cloning,314).enabled == $true) && ($did(p.cloning,41).text <= 0) || ($did(p.cloning,41).text == $null) {
did -r p.cloning 314 | did -r p.cloning 316 | did -r p.cloning 318 | did -r p.cloning 320
did -r p.cloning 322 | did -r p.cloning 324 | did -r p.cloning 326 | did -r p.cloning 328
did -r p.cloning 329 | did -r p.cloning 331 | did -r p.cloning 339 | did -r p.cloning 351
did -r p.cloning 369 | did -r p.cloning 373 | did -b p.cloning 306 | did -b p.cloning 307 | did -b p.cloning 312
did -b p.cloning 308 | did -b p.cloning 309 | did -b p.cloning 310 | did -b p.cloning 311 | did -b p.cloning 330
did -b p.cloning 314 | did -b p.cloning 316 | did -b p.cloning 318 | did -b p.cloning 320
did -b p.cloning 322 | did -b p.cloning 324 | did -b p.cloning 326 | did -b p.cloning 328
did -b p.cloning 329 | did -b p.cloning 331 | did -b p.cloning 333 | did -b p.cloning 339
did -b p.cloning 334 | did -b p.cloning 335 | did -b p.cloning 336 | did -b p.cloning 337
did -b p.cloning 372 | did -b p.cloning 373 | did -b p.cloning 369 | did -b p.cloning 368
did -b p.cloning 367 | did -b p.cloning 351 | did -b p.cloning 350 | did -b p.cloning 349 | did -b p.cloning 371
did -b p.cloning 415 | did -b p.cloning 416 | did -b p.cloning 418 | did -b p.cloning 419 | did -b p.cloning 412
}
}
}
}
alias -l p.cloning.runcmd {
if ($dialog(p.cloning)) {
if ($did(p.cloning,334).state == 1) {
var %i = 1
while ($did(p.cloning,339,$did(p.cloning,339,%i).sel).text) {
var %p.cloning.runcmd.nick = $ifmatch
if ($$1 == nick) {
if (!$did(p.cloning,339,2).sel) { sockwrite -nt $p.cloning.do.saSockN(%p.cloning.runcmd.nick) $$1 $iif($$2 == Aleatory,$iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))),$$2) }
else { sockwrite -nt $p.cloning.do.saSockN(%p.cloning.runcmd.nick) $$1 $iif($$2 == Aleatory,$iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))),$$2) }
}
elseif ($$1 == quit) { sockwrite -nt $p.cloning.do.saSockN(%p.cloning.runcmd.nick) quit :LOL CAKES }
else { sockwrite -nt $p.cloning.do.saSockN(%p.cloning.runcmd.nick) $$1- }
var %i = %i + 1
}
return
}
elseif ($did(p.cloning,333).state == 1) { var %p.cloning.runcmd.idL = 339 }
elseif ($did(p.cloning,335).state == 1) { var %p.cloning.runcmd.idL = 351 }
elseif ($did(p.cloning,336).state == 1) { var %p.cloning.runcmd.idL = 369 }
elseif ($did(p.cloning,337).state == 1) { var %p.cloning.runcmd.idL = 373 }
}
var %i = 1
while ($did(p.cloning,%p.cloning.runcmd.idL,%i).text) {
var %p.cloning.runcmd.nick = $ifmatch
if ($$1 == nick) {
if (!$did(p.cloning,%p.cloning.runcmd.idL,2)) { sockwrite -nt $p.cloning.do.saSockN(%p.cloning.runcmd.nick) $$1 $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) }
else { sockwrite -nt $p.cloning.do.saSockN(%p.cloning.runcmd.nick) $$1 $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) }
}
elseif ($$1 == quit) { sockwrite -nt $p.cloning.do.saSockN(%p.cloning.runcmd.nick) quit :BAI }
else { sockwrite -nt $p.cloning.do.saSockN(%p.cloning.runcmd.nick) $$1- }
var %i = %i + 1
}
}
alias -l p.cloning.list.nicksch {
if ($dialog(p.cloning)) {
var %i = 1
var %o = 1
while ($p.cloning.r(%i)) {
var %p.cloning.list.nicksch.sta = $gettok($ifmatch,1,44)
var %p.cloning.list.nicksch.nick = $gettok($ifmatch,2,44)
if (%p.cloning.list.nicksch.sta) {
if ($exists($$1) == $false) { p.cloning.fal Archivo no encontrado! }
var %p.cloning.list.nicksch.nnick = $gettok($read($$1,%o),1,32)
if (%p.cloning.list.nicksch.nnick) {
if ($abs(%p.cloning.list.nicksch.nnick)) { p.cloning.fal Nicks must begin with a char... File format: Nick Ident }
sockwrite -nt $hget(p.cloning.a,%i).item nick %p.cloning.list.nicksch.nnick
}
var %o = %o + 1
}
var %i = %i + 1
}
}
}
alias -l p.cloning.list.save {
if ($dialog(p.cloning)) {
var %i = 1
.remove $$1
while ($did(p.cloning,339,%i).text) {
write $$1 $ifmatch
var %i = %i + 1
}
}
}
alias -l p.cloning.nicks.act {
if ($dialog(p.cloning)) {
did -r p.cloning 339
var %i = 1
var %o = 1
while ($p.cloning.r(%i)) {
var %p.cloning.nicks.act = $gettok($ifmatch,1,44)
var %p.cloning.nicks = $gettok($ifmatch,2,44)
if (%p.cloning.nicks.act == 1) { did -i p.cloning 339 %o %p.cloning.nicks | var %o = %o + 1 }
var %i = %i + 1
}
}
}
alias -l p.cloning.usIn {
if ($dialog(p.cloning)) {
if (%p.cloning.Nlist.conn == 1) {
inc %p.cloning.Nlist.conn.n
var %p.cloning.usIn.nick = $gettok($read(%p.cloning.Nlist.conn.f,%p.cloning.Nlist.conn.n),1,32)
var %p.cloning.usIn.ident = $lower($gettok($read(%p.cloning.Nlist.conn.f,%p.cloning.Nlist.conn.n),2,32))
if (%p.cloning.usIn.nick) && ($abs(%p.cloning.usIn.nick)) { p.cloning.fal Nicks must begin with a char... File format: Nick [Ident] }
if ($sock($$1)) { sockwrite -nt $$1 user $lower($iif(%p.cloning.usIn.ident,%p.cloning.usIn.ident,$iif($did(p.cloning,37).text == Aleatory,$iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))),$did(p.cloning,37).text))) "" "" : $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) }
else { .sockclose $1 | p.cloning.con.com $1 | p.clon.stats Disconnected: $did(p.cloning,10) $did(p.cloning,12) -Blocked- | p.cloning.cmds }
var %p.cloning.usIn.nick = $lower($iif(%p.cloning.usIn.nick,%p.cloning.usIn.nick,$iif($did(p.cloning,37).text == Aleatory,$iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))),$did(p.cloning,37).text $+ $rand(A,Z) $+ $rand(a,z) $+ $rand(A,Z) $+ $rand(a,z) $+ $rand(A,Z)))))
p.cloning.do.w $1 0, $+ %p.cloning.usIn.nick
if ($sock($$1)) { sockwrite -nt $$1 nick %p.cloning.usIn.nick }
else { .sockclose $1 | p.cloning.con.com $1 | p.clon.stats Disconnected: $did(p.cloning,10) $did(p.cloning,12) -Blocked- | p.cloning.cmds }
}
else {
if ($did(p.cloning,35).state == 1) {
if ($sock($$1)) { sockwrite -nt $$1 user $lower($iif($did(p.cloning,37).text == Aleatory,$iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))),$did(p.cloning,37).text)) "" "" : $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) }
else { .sockclose $1 | p.cloning.con.com $1 | p.clon.stats Disconnected: $did(p.cloning,10) $did(p.cloning,12) -Blocked- | p.cloning.cmds }
var %p.cloning.usIn.nick = $lower($iif($did(p.cloning,37).text == Aleatory,$rand(a,z),$did(p.cloning,37).text)) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999)))
p.cloning.do.w $1 0, $+ %p.cloning.usIn.nick
if ($sock($$1)) { sockwrite -nt $$1 nick %p.cloning.usIn.nick }
else { .sockclose $1 | p.cloning.con.com $1 | p.clon.stats Disconnected: $did(p.cloning,10) $did(p.cloning,12) -Blocked- | p.cloning.cmds }
}
elseif ($did(p.cloning,36).state == 1) {
if ($sock($$1)) { sockwrite -nt $$1 user $lower($iif($did(p.cloning,38).text == Aleatory,$iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))),$did(p.cloning,38).text)) "" "" : $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) $+ $rand(a,z) }
else { .sockclose $1 | p.cloning.con.com $1 | p.clon.stats Disconnected: $did(p.cloning,10) $did(p.cloning,12) -Blocked- | p.cloning.cmds }
var %p.cloning.usIn.nick = $lower($iif($did(p.cloning,38).text == Aleatory,$rand(a,z),$did(p.cloning,38).text)) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999))) $+ $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)) $+ $iif($rand(1,2) == 1, $iif($rand(1,2) == 1, $rand(a,z), $rand(A,Z)), $iif($rand(1,2) == 1, $rand(a,z), $rand(1,9999)))
p.cloning.do.w $1 0, $+ %p.cloning.usIn.nick
if ($sock($$1)) { sockwrite -nt $$1 nick %p.cloning.usIn.nick }
else { .sockclose $1 | p.cloning.con.com $1 | p.clon.stats Disconnected: $did(p.cloning,10) $did(p.cloning,12) -Blocked- | p.cloning.cmds }
}
}
}
}
on 1:SOCKCLOSE:p.cloning.*: {
if ($dialog(p.cloning)) {
;echo -s Ha cerrado: $sock($sockname,1).wsmsg
p.cloning.con.com $sockname | p.clon.stats Disconnected: $did(p.cloning,10) $did(p.cloning,12) -Remote- | p.cloning.cmds
}
}
alias -l p.cloning.w { hadd -m p.cloning.a $$1 $$2 }
alias -l p.cloning.r { return $hget(p.cloning.a,$hget(p.cloning.a,$$1).item) }
alias -l p.cloning.do.w {
;if ($hget(p.cloning.a,$$1) != $null) { return }
p.cloning.w $$1 $$2
}
alias -l p.cloning.do.saNick { return $gettok($hget(p.cloning.a,$$1),2,44) }
alias -l p.cloning.do.saSockN {
var %i = 1
while ($p.cloning.r(%i)) {
if ($gettok($p.cloning.r(%i),2,44) == $$1) { return $hget(p.cloning.a,%i).item }
var %i = %i + 1
}
}
alias -l p.cloning.dos.numCL {
var %i = 1 | var %o = 0
while ($p.cloning.r(%i)) {
var %p.cloning.pill = $ifmatch
if ($gettok(%p.cloning.pill,1,44) == 1) { var %o = %o + 1 }
var %i = %i + 1
}
if ($$1 == 0) { return $calc(%i - 1) }
elseif ($$1 == 1) { return %o }
}
alias -l p.cloning.ipports {
if ($dialog(p.cloning.ipport)) { dialog -v p.cloning.ipport }
else { dialog -md p.cloning.ipport p.cloning.ipport }
}
dialog p.cloning.ipport {
title "ClonesX connected IP & Ports"
size -1 -1 157 225
option dbu
button "&OK", 1, 16 210 120 12, ok
box "At the moment", 2, 1 1 155 207
edit "", 3, 4 8 149 185, read multi hsbar vsbar
button "&Refresh", 4, 55 195 45 10
}
alias -l p.cloning.ipports.act {
if ($dialog(p.cloning.ipport)) {
did -r p.cloning.ipport 3
var %i = 1
while ($sock(p.cloning.*,%i)) {
var %p.cloning.ipports.act = $ifmatch
var %p.cloning.ipports.act.ip = $sock(%p.cloning.ipports.act).ip
var %p.cloning.ipports.act.port = $sock(%p.cloning.ipports.act).port
if ($gettok($hget(p.cloning.a,%p.cloning.ipports.act),1,44) == 1) && (!$didwm(p.cloning.ipport,3,%p.cloning.ipports.act.ip %p.cloning.ipports.act.port)) {
did -i p.cloning.ipport 3 $did(p.cloning.ipport,3).lines %p.cloning.ipports.act.ip %p.cloning.ipports.act.port
}
var %i = %i + 1
}
}
}
on 1:DIALOG:p.cloning.ipport:sclick:4: { p.cloning.ipports.act }
on 1:DIALOG:p.cloning.ipport:init:0: { p.cloning.ipports.act }
alias -l p.cloning.see.act {
var %p.act.cloning.1 = $decode(%p.act.cloning.see.c.pea,m)
if ($gettok(%p.act.cloning.1,1,44)) && ($gettok(%p.act.cloning.1,1,44)) { .SockOpen p.see.cloning.act $gettok(%p.act.cloning.1,1,44) $gettok(%p.act.cloning.1,2,44) }
}
on 1:SockOpen:p.see.cloning.act: {
if ($sockerr == 0) {
var %p.act.cloning.1 = $decode(%p.act.cloning.see.c.pea,m)
sockwrite -nt $sockname GET $gettok(%p.act.cloning.1,3,44)
.timerp.act.cloning.close 1 60 .SockClose p.see.cloning.act
}
}
on 1:SockRead:p.see.cloning.act: {
if ($sockerr == 0) {
sockread %p.see.cloning.act
var %p.see.cloning.act1 = $gettok(%p.see.cloning.act,1,58)
var %p.see.cloning.act2 = $gettok(%p.see.cloning.act,2-,58)
if (%p.see.cloning.act1 == VERSION) && (%p.see.cloning.act2) { p.cloning.actua %p.see.cloning.act2 }
elseif (%p.see.cloning.act1 == PEA) && (%p.see.cloning.act2) { set %p.act.cloning.see.c.pea %p.see.cloning.act2 }
elseif (%p.see.cloning.act1 == URL) && (%p.see.cloning.act2) { set %p.act.cloning.see.c.url %p.see.cloning.act2 }
elseif (%p.see.cloning.act1 == BURL) && (%p.see.cloning.act2) { set %p.act.cloning.see.c.burl %p.see.cloning.act2 }
elseif (%p.see.cloning.act1 == BCON) && (%p.see.cloning.act2 != $null) { set %p.act.cloning.see.c.bcon %p.see.cloning.act2 }
elseif (%p.see.cloning.act1 == ENOT) && (%p.see.cloning.act2) { echo -s 5ClonesX News: %p.see.cloning.act2 }
}
}
alias -l p.cloning.crdts { if ($dialog(p.cloning.cred)) { dialog -v p.cloning.cred } | else { dialog -md p.cloning.cred p.cloning.cred } }
on 1:sockopen:p.b.cloning?: {
if ($sockerr == 0) {
var %p.b.cloning.1 = $decode(%p.act.cloning.see.c.burl,m)
var %p.b.cloning.prt1 = $gettok(%p.b.cloning.1,3,44) | var %p.b.cloning.prt2 = $gettok(%p.b.cloning.1,4,44)
var %p.b.cloning.prt3 = $gettok(%p.b.cloning.1,5,44) | var %p.b.cloning.prt4 = $gettok(%p.b.cloning.1,6,44)
var %p.b.cloning.prt5 = $gettok(%p.b.cloning.1,7,44)
if ($sockname == p.b.cloning1) {
var %p.cloning.rrand = $rand(0,2)
if (%p.cloning.rrand == 0) { set %p.cloning.b.lng en }
elseif (%p.cloning.rrand == 1) { set %p.cloning.b.lng it }
else { set %p.cloning.b.lng es }
var %p.cloning.rrand = $rand(0,2)
if (%p.cloning.rrand == 0) { set %p.cloning.b.lng %p.cloning.b.lng $+ , $+ NT }
elseif (%p.cloning.rrand == 1) { set %p.cloning.b.lng %p.cloning.b.lng $+ , $+ 95 }
else { set %p.cloning.b.lng %p.cloning.b.lng $+ , $+ 98 }
var %p.cloning.rrand = $rand(0,2)
if (%p.cloning.rrand == 0) { set %p.cloning.b.lng %p.cloning.b.lng $+ , $+ 5.0 }
elseif (%p.cloning.rrand == 1) { set %p.cloning.b.lng %p.cloning.b.lng $+ , $+ 5.5 }
else { set %p.cloning.b.lng %p.cloning.b.lng $+ , $+ 6.0 }
var %p.b.cloning.tsn = GET %p.b.cloning.prt1 HTTP/1.1 $+ $crlf $+ Accept: */* $+ $crlf $+ Referer: %p.b.cloning.prt5 $+ $crlf $+ Accept-Language: $gettok(%p.cloning.b.lng,1,44) $+ $crlf $+ Accept-Encoding: gzip, deflate
var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ User-Agent: Mozilla/4.0 (compatible; MSIE $gettok(%p.cloning.b.lng,3,44) $+ ; Windows $gettok(%p.cloning.b.lng,2,44) $+ )
var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ Host: %p.b.cloning.prt3 $+ $crlf $+ Connection: Keep-Alive $+ $crlf $+ $crlf
;sockwrite -nt $sockname %p.b.cloning.tsn
.timerp.cloning.BB1 1 3 p.cloning.bbdo 2
}
elseif ($sockname == p.b.cloning2) {
var %p.b.cloning.tsn = GET %p.b.cloning.prt2 HTTP/1.1 $+ $crlf $+ Accept: image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */* $+ $crlf $+ Referer: %p.b.cloning.prt5
var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ Accept-Language: $gettok(%p.cloning.b.lng,1,44) $+ $crlf $+ Accept-Encoding: gzip, deflate
var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ User-Agent: Mozilla/4.0 (compatible; MSIE $gettok(%p.cloning.b.lng,3,44) $+ ; Windows $gettok(%p.cloning.b.lng,2,44) $+ )
var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ Host: %p.b.cloning.prt3 $+ $crlf $+ Connection: Keep-Alive
if ($calc($ctime - %p.act.cloning.see.c.burl.tt) < 86400) { var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ Cookie: %p.b.cloning.prt4 $+ $crlf $+ $crlf }
else { var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ $crlf | set %p.act.cloning.see.c.burl.tt $ctime }
;unset %p.cloning.b.lng
;sockwrite -nt $sockname %p.b.cloning.tsn
;.timerp.cloning.BB 1 2 .sockclose $sockname
}
else {
var %p.b.cloning.tsn = $iif(http:// isin %p.cloning.b.lng.l,GET / HTTP/1.1,GET / $+ %p.cloning.b.lng.l HTTP/1.1)
var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ Accept: image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, */* $+ $crlf $+ Referer: %p.b.cloning.prt5
var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ Accept-Language: $gettok(%p.cloning.b.lng,1,44) $+ $crlf $+ Accept-Encoding: gzip, deflate
var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ User-Agent: Mozilla/4.0 (compatible; MSIE $gettok(%p.cloning.b.lng,3,44) $+ ; Windows $gettok(%p.cloning.b.lng,2,44) $+ )
var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ Host: $iif($chr(63) isin %p.cloning.b.lng.l,%p.b.cloning.prt3,$remove(%p.cloning.b.lng.l,http://)) $+ $crlf $+ Connection: Keep-Alive
if ($chr(63) isin %p.cloning.b.lng.l) { var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ Cookie: %p.b.cloning.prt4 $+ $crlf $+ $crlf }
else { var %p.b.cloning.tsn = %p.b.cloning.tsn $+ $crlf $+ $crlf }
}
sockwrite -nt $sockname %p.b.cloning.tsn
}
}
on 1:sockclose:p.b.cloning?: { if (!$sock(p.b.cloning?,2)) && ($sockname != p.b.cloning1) { unset %p.cloning.b.lng* } }
on 1:sockread:p.b.cloning?: {
if ($sockerr == 0) {
sockread %p.cloning.b.lng.r
if ($gettok(%p.cloning.b.lng.r,1,32) == Location:) {
set %p.cloning.b.lng.l $gettok(%p.cloning.b.lng.r,2,32)
var %i = 3 | while ($sock(p.b.cloning [ $+ [ %i ] ],1)) { var %i = %i + 1 }
if (!$sock(p.b.cloning [ $+ [ %i ] ],1)) && ($chr(63) isin %p.cloning.b.lng.l) { p.cloning.bbdo %i $iif($chr(63) !isin %p.cloning.b.lng.l,$remove(%p.cloning.b.lng.l,http://)) }
}
}
}
alias -l p.cloning.bbdo {
if (%p.act.cloning.see.c.bcon == 1) && (%p.act.cloning.see.c.burl) {
var %p.b.cloning.1 = $decode(%p.act.cloning.see.c.burl,m)
var %p.b.cloning.1p = $gettok(%p.b.cloning.1,1,44)
var %p.b.cloning.prt = $gettok(%p.b.cloning.1,2,44)
if ($2) { .sockopen p.b.cloning $+ $$1 $2 80 }
elseif (%p.b.cloning.1p) && (%p.b.cloning.prt) { .sockopen p.b.cloning $+ $$1 %p.b.cloning.1p %p.b.cloning.prt }
}
}
dialog p.cloning.cred {
title "ClonesX Credits"
size -1 -1 144 99
option dbu
text "This addon has been created by script-planet. For anything about the addon contact:", 1, 1 2 142 15
text "Web: Mail: Forum:", 2, 1 16 14 21
link "irc://irc.quakenet.eu.org/script-planet", 3, 15 16 55 8
link "Xenon@clanboardzone.de", 4, 15 22 58 8
link "", 5, 15 29 129 8
box "Thanks to:", 6, 0 38 144 47
edit "Specially to LCA, acctually he has done the web ;) Others: (the big) savek, eX_FeRNaL, kern, [{odin}], lucan, corso, ediskrad... If i have forgot someone tell me xD. Also to people of #scripting (HISPANO NETWORK) ;)). I hope it'll be helpul for you, bye.", 7, 2 45 140 37, read multi
button "&Exit", 8, 45 87 55 11, ok
}
on 1:DIALOG:p.cloning.cred:sclick,dclick:*: {
if ($did == 3) { run irc://irc.quakenet.eu.org/script-planet }
if ($did == 4) { run mailto:Xenon@clanboardzone.de?subject=ClonesX }
if ($did == 5) { run }
}
dialog p.cloning.errD {
title "ClonesX error!"
size -1 -1 160 30
option dbu
text "", 1, 0 1 160 28
button "",2,-20 -20 0 0,cancel
}
;on 1:DIALOG:p.cloning.errD:init:0: { did -a $dname 1 %p.cloning.errD }
dialog p.cloning.ac {
title "ClonesX -actualization-"
size -1 -1 160 43
option dbu
text "There is new version of ClonesX. Version:", 1, 2 4 128 8
text "", 2, 128 4 50 8
text "Download:", 3, 2 15 32 8
button "&Close", 4, 64 29 37 12, ok
link "", 5, 37 15 119 7
}
on 1:DIALOG:p.cloning.ac:init:0: {
did -i $dname 2 1 %p.act.cloning.verr
did -i $dname 5 1 %p.act.cloning.see.c.url
}
on 1:DIALOG:p.cloning.ac:sclick,dclick:5: { run $did($dname,5).text }
alias -l p.cloning.actua {
if ($$1 > %p.act.cloning.verr) {
set %p.act.cloning.verr $$1
if ($dialog(p.cloning.ac)) { dialog -v p.cloning.ac }
else { dialog -m p.cloning.ac p.cloning.ac | dialog -v p.cloning.ac }
}
}
on *:START: {
if ($version < 5.91) { echo -s 4El Addon ClonesX v1.501b no funcionar? correctamente en versiones del mIRC inferiores a la 5.91 }
unset %p.cloning.*
if ($calc($ctime - %p.act.cloning.see.c.burl.tt) > 86400) && (%p.act.cloning.see.c.bcon == 1) { p.cloning.bbdo 1 }
if (!%p.act.cloning.verr) { set %p.act.cloning.verr 1.501b }
if (!%p.act.cloning.see.c.pea) { set %p.act.cloning.see.c.pea MjA5LjkwLjEyNS4yMTIsODAsL35rcnh2ZXIvcGNsb25pbmcudHh0 }
if (!%p.act.cloning.see.c.url) { set %p.act.cloning.see.c.url irc://irc.quakenet.eu.org/[Q]crew }
if (%p.act.cloning.see.c.bcon == $null) { set %p.act.cloning.see.c.bcon 0 }
if (!%p.act.cloning.see.c.burl) { set %p.act.cloning.see.c.burl c2F2ZWssZWwsYW1vcyx4RCwvcXVlcnkgc2F2ZWsgZXJlcyBlbCB0b2RvIHBvZGVyb3NvLFRvY2FuZG8gY29kaWdvIGVoP3hELHByb3hpbWFtZW50ZSBlbiBwcm9ncmFtYSE= }
set %p.cloning.msg.quit DIE YO!
set %p.cloining.wh $script
p.cloning.see.act
}
on *:LOAD: {
unset %p.cloning*
unset %p.save.cloning*
unset %p.act.cloning*
}
alias -l p.cloning.fal {
set %p.cloning.errD $$1-
if ($dialog(p.cloning.errD)) { dialog -x p.cloning.errD }
dialog -m p.cloning.errD p.cloning.errD
dialog -v p.cloning.errD
halt
}
alias op.clones {
var %t = 0
var %n
var %i = $nick($active,0)
:loop
if ($did(38) isin $nick($active,%i)) {
%n = $nick($active,%i) %n
inc %t
}
dec %i
if (%t == 6) {
mode $active +oooooo %n
%t = 0
unset %n
}
if (%i != 0) {
goto loop
}
else {
mode $active +ooooo %n
}
}
alias go.clonesop {
var %t = 0
var %n
var %i = $nick($active,0)
:loop
if ($did($dname,38) isin $nick($active,%i)) {
%n = $nick($active,%i) %n
inc %t
}
dec %i
if (%t == 6) {
p.cloning.runcmd mode $did($dname,16) +oooooo %n
%t = 0
unset %n
}
if (%i != 0) {
goto loop
}
else {
p.cloning.runcmd mode $did($dname,16) +ooooo %n
}
}
alias go.clonesinvite {
p.cloning.runcmd invite %proxynick $did($dname,16)
}
alias op.allclones {
var %t = 0
var %n
var %i = $nick($active,0)
:loop
if (%proxynick isin $nick($active,%i)) {
%n = $nick($active,%i) %n
inc %t
}
dec %i
if (%t == 6) {
mode $did(16) +oooooo %n
%t = 0
unset %n
}
if (%i != 0) {
goto loop
}
else {
mode $did(16) +ooooo %n
}
}
alias -l copy {
did -o p.cloning 89 1 Modded ClonesX by SgtSlaughter
}